@@ -20,7 +20,7 @@ use Term::Choose::Util qw( term_size );
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
 use App::YTDL::Helper        qw( get_filename check_mapping_stdout encode_fs sanitize_for_path );
-use App::YTDL::History       qw( add_uploader_to_history write_uploader_history_to_file );
+use App::YTDL::History       qw( add_uploader_to_history new_uploader_to_history_file );
 use App::YTDL::InfoPrint     qw( linefolded_print_info );
 use App::YTDL::Options       qw( set_options );
 use App::YTDL::SelectQuality qw( fmt_quality set_preferred_qualities );
@@ -169,7 +169,7 @@ sub get_download_infos {
         }
     }
     print "\n";
-    write_uploader_history_to_file( $opt ) if $opt->{max_size_history};
+    new_uploader_to_history_file( $opt ) if $opt->{max_size_history};
     if ( ! $opt->{nr_videos} ) {
         print locate( 1, 1 ), cldown;
         say "No videos";
